package dev.fitko.fitconnect.client.steps.subscriber;

import dev.fitko.fitconnect.api.domain.model.metadata.Metadata;
import dev.fitko.fitconnect.api.domain.model.metadata.attachment.Attachment;
import dev.fitko.fitconnect.api.domain.model.metadata.data.Data;
import dev.fitko.fitconnect.api.domain.model.submission.SubmissionForPickup;
import dev.fitko.fitconnect.api.services.Subscriber;

import java.util.Set;
import java.util.UUID;

public interface RequestSubmissionStep {

    /**
     * Loads a list of available {@link SubmissionForPickup} that were submitted to the {@link Subscriber}.
     *
     * @param destinationId unique identifier for a destination
     * @param limit         number of submissions in result (max. is 500)
     * @param offset        position in the dataset
     * @return set of unique of available submissions for pickup
     */
    Set<SubmissionForPickup> getAvailableSubmissions(UUID destinationId, int offset, int limit);

    /**
     * Loads a list of available {@link SubmissionForPickup} that were submitted to the {@link Subscriber}.
     *
     * @param destinationId unique identifier for a destination
     * @return set of unique available submissions for pickup
     */
    Set<SubmissionForPickup> getAvailableSubmissions(UUID destinationId);

    /**
     * Loads a single {@link SubmissionForPickup} by id.
     *
     * @param submissionId unique identifier of a {@link SubmissionForPickup}
     * @return next step to load availbale {@link Metadata}, {@link Data} and {@link Attachment}s
     */
    ConfirmSubmissionStep requestSubmission(UUID submissionId);
}
